@@ -63,26 +63,26 @@ class Web(Tier):
 
   def cli(self, args):
     knife = Knife()
-    output = knife.ssh(args.environment, self.tier, 
-        "ps -ef | egrep \"cli.py\" | grep -v \"sh -c\" | grep -v grep ")
+    output = knife.ssh("ps -ef | egrep \"cli.py\" | grep -v \"sh -c\" | grep -v grep ",
+        args.environment, self.tier) 
     print output
   
   def cli_count(self, args):
     knife = Knife()
-    output = knife.ssh(args.environment, self.tier, 
-        "ps -ef | egrep \"cli.py\" | grep -v \"sh -c\" | grep -v grep | wc -l")
+    output = knife.ssh("ps -ef | egrep \"cli.py\" | grep -v \"sh -c\" | grep -v grep | wc -l",
+        args.environment, self.tier) 
     print output
 
   def dj(self, args):
     knife = Knife()
-    output = knife.ssh(args.environment, self.tier, 
-        "ps -ef | egrep \"delayed_job\" | grep -v \"sh -c\" | grep -v grep ")
+    output = knife.ssh("ps -ef | egrep \"delayed_job\" | grep -v \"sh -c\" | grep -v grep ",
+        args.environment, self.tier)
     print output
   
   def dj_count(self, args):
     knife = Knife()
-    output = knife.ssh(args.environment, self.tier, 
-        "ps -ef | egrep \"delayed_job\" | grep -v \"sh -c\" | grep -v grep | wc -l")
+    output = knife.ssh("ps -ef | egrep \"delayed_job\" | grep -v \"sh -c\" | grep -v grep | wc -l",
+        args.environment, self.tier)
     print output
 
   def list_zombies(self, args):
