@@ -62,7 +62,7 @@ puts nodeinfo.to_json""" % (env, tier)
     os.unlink(temp)
     return output
 
-  def ssh_one(self, env, tier, cmd):
+  def ssh_one(self, cmd, env, tier):
     temp = self.get_pemfile(env)
     k = paramiko.RSAKey.from_private_key_file(temp)
     list = self.search(env, tier)
